# Installation

- [Installing the plugin using pip (recommended)](./1-installing-plugin.md)
- [Installing the plugin using git](./2-installing-plugin-git.md)
- [Installing the plugin using Docker](./3-installing-plugin-docker.md)